
export default class Storage {
    private readonly prefix: string;

    constructor(type: string = "default") {
        this.prefix = type;
    }

    public get<T>(key: string, defaultValue?: T): T | undefined {
        const value = localStorage.getItem(this.getKey(key));
        if (value === null) {
            return defaultValue;
        }
        try {
            return JSON.parse(value) as T;
        } catch {
            return defaultValue;
        }
    }

    public set<T>(key: string, value: T): void {
        const serializedValue = JSON.stringify(value);
        localStorage.setItem(this.getKey(key), serializedValue);
    }

    public remove(key: string): void {
        localStorage.removeItem(this.getKey(key));
    }

    public clear(): void {
        for (let i = 0; i < localStorage.length; i++) {
            const key = localStorage.key(i);
            if (key && key.startsWith(`${this.prefix}:`)) {
                localStorage.removeItem(key);
            }
        }
    }

    private getKey(key: string): string {
        return `${this.prefix}:${key}`;
    }
}