import * as path from 'path'
import dts from "vite-plugin-dts";
import { defineConfig } from "vite";
import pkg from "./package.json";

export default defineConfig({
    plugins: [
        dts({
            rollupTypes: true,
        }),
    ],
    build: {
        cssCodeSplit: true,
        lib: {
            // Could also be a dictionary or array of multiple entry points
            entry: "./package.ts",
            name: 'package',
            formats: ["es", "cjs", "umd"],
            fileName: format => `package.${format}.js`
        },
        rollupOptions: {
            // make sure to externalize deps that should not be bundled
            // into your library
            input: {
                package: path.resolve(__dirname, "./package.ts"),
            },
            external: id => {
                // make all peerDependencies external
                return Object.keys(pkg.peerDependencies || {}).includes(id);
            },
            output: {
                exports: "named",
                globals: {
                    vue: 'Vue',
                },
            },
        },
    }
})